@@ -1,4 +1,3 @@
 from .mainfunc import belongs_to, lookup, dist, coordinate
 
-if __name__ != "__main__":
-    HOMETOWN = lookup("广元昭化")
+__version__ = "0.2.6"
